%% TO4 - Fresnel diffraction: intensity profile of a 1D-single slit

% by Klaus Albers and Alexander Gling
% Photonics Lab, Muenster University of Applied Sciences

% This program calculates the diffraction pattern of a singel slit in Fresnel approximation. The x-axis is scaled in pixels.
% Additionally, measured data can be imported and plotted together with the
% simulated data. For that purpose one can shift the experimental data by a constant value in x-dirchtion and 
% subtract a constant offset. All data is exported as an *.png image.

%% Main program
function fresnel_slit

    clc;
    clear all;
    close all;

%% User input

% ++++++++++++ Change below ++++++++++++++++++++++++++++

    fileout_graph='fresnel_test.png'; % output file name
    % filein='einzelspalt_C_fernfeld.lvm'; % input file name
    filein='einzelspalt_C_nahfeld_76mm.lvm'; % input file name
    
    shiftx=1005.5; % shift input data in x direction /pixel
    offsety=420; % subtract constant offset from input data 
    flag=1; % 0 - show calculated data only, 1 - show measured data and calculated data, 2 - show raw measured data only  
    bs1=0.48; % width fo the slit / mm
    bm1=80;  % width of the CCD or screen / pixel
    z=77.5; % distance /mm
    
% ++++++++++++ Change above ++++++++++++++++++++++++++++    

    pixelsize=0.014; % pixel size of CCD /mm
    lambda=635e-6; % wavelength / mm
    F=bs1^2/lambda/z/4; % Fresnel number accordung to Hodgen
    N=600; % sampling 
    k=2*pi/lambda; % wavevector

%% Calculation    
    x1=linspace(-bs1/2,bs1/2,N);
    x2=linspace(-bm1/2,bm1/2,N);
    step=bs1/N;
    E0=ones(1,length(x1)); %E-field distribution at z=0, homogenious slit
    Em1=zeros(size(x2)); %E-field distribution at z, fill with zeros

    for run=1:length(x2) %calculate fresnel integral (Demtroeder)
        Em1(run)=sqrt(2*pi*z/(-i*k))*exp(-i*k*z)/(i*lambda*z)*sum(step*E0.*exp((-i*k*(x1-pixelsize*x2(run)).^2)/(2*z)));
    end
    Im1=Em1.*conj(Em1); %calculate intensity
    Im1=Im1/max(Im1); % normalize intensity
   
%% Import and plot measured data
    if (flag==1)
        datain=dlmread(filein);
        xdata=datain(:,1);
        ydata=datain(:,2);
        xdata=xdata-shiftx;
        ydata=ydata-offsety;
        ydata=ydata/max(ydata);
        figure(1);
        fs=14; fn='times'; lw=2;
        plot(xdata,ydata,'--ro','linewidth',lw);
        hold on;
        lw=3;
        plot(x2,Im1,'linewidth',lw);
        set(gca,'fontsize',fs,'fontname',fn);
        xlabel('x (pixel)');
        ylabel('I (arb. u.)');
        xlim([-bm1/2 bm1/2]);
        ylim([-0.02 1.02]);
        legend('measured data','calculated data');
        title(['z = ',num2str(z),' mm, Fresnel number = ',num2str(F)]) 
    end;
    
     if (flag==2)  
        datain=dlmread(filein);
        xdata=datain(:,1);
        ydata=datain(:,2);
        figure(1);
        fs=14; fn='times'; lw=2;
        plot(xdata,ydata,'--ro','linewidth',lw);
        set(gca,'fontsize',fs,'fontname',fn);
        xlabel('x (pixel)');
        ylabel('I (arb. u.)');
        xlim([0 length(xdata)]);
        legend('measured data'); 
    end;
        
    if (flag==0)
        figure(1);
        fs=14; fn='times'; lw=3;
        plot(x2,Im1,'linewidth',lw);
        set(gca,'fontsize',fs,'fontname',fn);
        title(['z = ',num2str(z),' mm, Fresnel number = ',num2str(F)]) 
        xlabel('x (pixel)');
        ylabel('I (arb. u.)');
        legend('calculated data');
    end;
    
%% Export data
    print('-dpng', '-r600',fileout_graph);
end
